#global prerel alpha

Summary:	LZMA compression utilities
Name:		xz
Version:	5.2.3
Release:	7.0.cf%{?dist}

# Scripts xz{grep,diff,less,more} and symlinks (copied from gzip) are
# GPLv2+, binaries are Public Domain (linked against LGPL getopt_long but it's
# OK), documentation is Public Domain
License:	GPLv2+ and Public Domain

URL:		http://tukaani.org/xz/
Source0:	http://tukaani.org/xz/xz-%{version}%{?prerel}.tar.xz
Source100:	colorxzgrep.sh
Source101:	colorxzgrep.csh
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-interpreter
BuildRequires:	sed
Requires:	xz-libs%{?_isa} = %{version}-%{release}

# For /usr/libexec/grepconf.sh (RHBZ#1189120).
# Unfortunately F21 has a newer version of grep which doesn't
# have grepconf, but we're only concerned with F22 here.
Requires:	grep >= 2.20-5

%description
XZ Utils are an attempt to make LZMA compression easy to use on free (as in
freedom) operating systems. This is achieved by providing tools and libraries
which are similar to use than the equivalents of the most popular existing
compression algorithms.

LZMA is a general purpose compression algorithm designed by Igor Pavlov as
part of 7-Zip. It provides high compression ratio while keeping the
decompression speed fast.

%package 	libs
Summary:	Libraries for decoding LZMA compression
License:	Public Domain
Obsoletes:	xz-compat-libs < %{version}-%{release}

%description 	libs
Libraries for decoding files compressed with LZMA or XZ utils.

%package	static
Summary:	Statically linked library for decoding LZMA compression
License:	Public Domain

%description	static
Statically linked library for decoding files compressed with LZMA or
XZ utils. Most users should *not* install this.

%package 	devel
Summary:	Devel libraries & headers for liblzma
License:	Public Domain
Requires:	xz-libs%{?_isa} = %{version}-%{release}

%description	devel
Devel libraries and headers for liblzma.

%package 	lzma-compat
Summary:	Older LZMA format compatibility binaries
# Just a set of symlinks to 'xz' + two Public Domain binaries
License:	Public Domain
Requires:	%{name}%{?_isa} = %{version}-%{release}
Obsoletes:	lzma < %{version}
Provides:	lzma = %{version}

%description  lzma-compat
The lzma-compat package contains compatibility links for older
commands that deal with the older LZMA format.

%prep
%setup -q -n %{name}-%{version}%{?prerel}

# add support for ppc64p7 arch (Power7 optimized)
for i in `find . -name config.sub`; do
	perl -pi -e "s/ppc64-\*/ppc64-\* \| ppc64p7-\*/" $i
done

%build
CFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64"
CXXFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64"
%ifarch %{power64}
	CFLAGS=`echo $CFLAGS | xargs -n 1 | sed 's|^-O2$|-O3|g' | xargs -n 100`
	CXXFLAGS=`echo $CXXFLAGS | xargs -n 1 | sed 's|^-O2$|-O3|g' | xargs -n 100`
%endif
export CFLAGS
export CXXFLAGS
%configure
sed -i	-e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
	-e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
	libtool
%make_build

%install
%make_install INSTALL="install -p"

# Remove stuff we don't want packaged
rm -f %{buildroot}%{_libdir}/*.la

# And we'll package the documentation ourselves...
rm -rf %{buildroot}%{_pkgdocdir}

%find_lang xz

# xzgrep colorization
%global profiledir %{_sysconfdir}/profile.d
mkdir -p %{buildroot}%{profiledir}
install -p -m 644 %{SOURCE100} %{buildroot}%{profiledir}
install -p -m 644 %{SOURCE101} %{buildroot}%{profiledir}

%check
LD_LIBRARY_PATH=$PWD/src/liblzma/.libs make check

%if (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig scriptlets replaced by RPM File Triggers from Fedora 28
%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig
%endif

%files -f xz.lang
%if 0%{?_licensedir:1}
%license COPYING*
%else
%doc COPYING*
%endif
%doc AUTHORS NEWS README THANKS TODO doc/*.txt
%{_bindir}/unxz
%{_bindir}/xz
%{_bindir}/xzcat
%{_bindir}/xzcmp
%{_bindir}/xzdec
%{_bindir}/xzdiff
%{_bindir}/xzegrep
%{_bindir}/xzfgrep
%{_bindir}/xzgrep
%{_bindir}/xzless
%{_bindir}/xzmore
%{_mandir}/man1/unxz.1*
%{_mandir}/man1/xz.1*
%{_mandir}/man1/xzcat.1*
%{_mandir}/man1/xzcmp.1*
%{_mandir}/man1/xzdec.1*
%{_mandir}/man1/xzdiff.1*
%{_mandir}/man1/xzegrep.1*
%{_mandir}/man1/xzfgrep.1*
%{_mandir}/man1/xzgrep.1*
%{_mandir}/man1/xzless.1*
%{_mandir}/man1/xzmore.1*
%{profiledir}/colorxzgrep.csh
%{profiledir}/colorxzgrep.sh

%files libs
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%{_libdir}/liblzma.so.5*

%files static
%if 0%{?_licensedir:1}
%license COPYING*
%else
%doc COPYING*
%endif
%{_libdir}/liblzma.a

%files devel
%doc doc/examples*/
%{_includedir}/lzma.h
%{_includedir}/lzma/
%{_libdir}/liblzma.so
%{_libdir}/pkgconfig/liblzma.pc

%files lzma-compat
%{_bindir}/lzcat
%{_bindir}/lzcmp
%{_bindir}/lzdiff
%{_bindir}/lzegrep
%{_bindir}/lzfgrep
%{_bindir}/lzgrep
%{_bindir}/lzless
%{_bindir}/lzma
%{_bindir}/lzmadec
%{_bindir}/lzmainfo
%{_bindir}/lzmore
%{_bindir}/unlzma
%{_mandir}/man1/lzcat.1*
%{_mandir}/man1/lzcmp.1*
%{_mandir}/man1/lzdiff.1*
%{_mandir}/man1/lzegrep.1*
%{_mandir}/man1/lzfgrep.1*
%{_mandir}/man1/lzgrep.1*
%{_mandir}/man1/lzless.1*
%{_mandir}/man1/lzma.1*
%{_mandir}/man1/lzmadec.1*
%{_mandir}/man1/lzmainfo.1*
%{_mandir}/man1/lzmore.1*
%{_mandir}/man1/unlzma.1*

%changelog
* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 5.2.3-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 5.2.3-6.0.cf
- ldconfig scriptlets replaced by RPM File Triggers from Fedora 28

* Sun Sep 17 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-5.0.cf
- Use %%make_build and %%make_install

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Fri Jul 28 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jan  2 2017 Paul Howarth <paul@city-fan.org> - 5.2.3-1.0.cf
- Update to 5.2.3
  - xz:
    - Always close a file before trying to delete it to avoid problems on some
      operating system and file system combinations
    - Fixed copying of file timestamps on Windows
    - Added experimental (disabled by default) sandbox support using Capsicum
      (FreeBSD ≥ 10)
  - C99/C11 conformance fixes to liblzma; the issues affected at least some
    builds using link-time optimizations
  - Fixed bugs in the rarely-used function lzma_index_dup()
  - Use of external SHA-256 code is now disabled by default
  - Changed CPU core count detection to use sched_getaffinity() on GNU/Linux
    and GNU/kFreeBSD
  - Fixes to the build-system and xz to make xz buildable even when encoders,
    decoders, or threading have been disabled from liblzma using configure
    options; these fixes added two new #defines to config.h: HAVE_ENCODERS and
    HAVE_DECODERS

* Tue Aug  2 2016 Paul Howarth <paul@city-fan.org> - 5.2.2-2.1.cf
- Specify build requirements

* Thu Feb 11 2016 Paul Howarth <paul@city-fan.org> - 5.2.2-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Sep 29 2015 Paul Howarth <paul@city-fan.org> - 5.2.2-1.0.cf
- Update to 5.2.2
  - Fixed bugs in QNX-specific code
  - Omitted the use of pipe2() even if it is available to avoid portability
    issues with some old Linux and glibc combinations
  - Updated German translation
  - Added project files to build static and shared liblzma (not the whole XZ
    Utils) with Visual Studio 2013 update 2 or later
  - Documented that threaded decompression hasn't been implemented yet; a
    5.2.0 NEWS entry describing multi-threading support had incorrectly said
    "decompression" when it should have said "compression"
- Remove xz-compat-libs unconditionally
- Explicitly package the documentation ourselves

* Fri Jul 10 2015 Paul Howarth <paul@city-fan.org> - 5.2.1-3.0.cf
- Remove xz-compat-libs (apart from F-22 builds) as it is not necessary
  (#1179193)

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 5.2.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Feb 27 2015 Paul Howarth <paul@city-fan.org> - 5.2.1-1.0.cf
- Update to 5.2.1
  - Fixed a compression-ratio regression in fast mode of LZMA1 and LZMA2; the
    bug is present in 5.1.4beta and 5.2.0 releases
  - Fixed a portability problem in xz that affected at least OpenBSD
  - Fixed xzdiff to be compatible with FreeBSD's mktemp, which differs from
    most other mktemp implementations
  - Changed CPU core count detection to use cpuset_getaffinity() on FreeBSD

* Thu Feb  5 2015 Paul Howarth <paul@city-fan.org> - 5.2.0-2.0.cf
- Depend on grep that contains grepconf.sh (#1189120)
- Use xz-compressed tarball

* Tue Jan  6 2015 Paul Howarth <paul@city-fan.org> - 5.2.0-1.0.cf
- Rebase per upstream release notes (#1023718)
  http://www.mail-archive.com/xz-devel@tukaani.org/msg00216.html
- fedora-review fixes, documentation/license fixes in spec

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-16.1.alpha.cf
- Only attempt colored xz*grep output on Fedora 22 onwards

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-16.alpha.cf
- xz*grep's output is colored iff grep's is (#1034846)

* Wed Aug 20 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-15.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Aug  7 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-14.alpha.cf
- Use %%license where possible

* Fri Jun 13 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-13.alpha.cf
- xzgrep: return 0 when at least one file matches (#1109122)

* Sat Jun  7 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-12.alpha.cf
- Drop ChangeLog; it's big and the excitement is summarised in NEWS

* Fri May 16 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-10.alpha.cf
- Add a -static sub-package (#547011)
- Modern rpm doesn't require buildroot cleaning

* Wed Apr  2 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-9.alpha.cf
- Better check the version of less binary (#1015924)
- Drop support for old distributions prior to F-16 because we're not building
  for them anyway

* Fri Jan 10 2014 Paul Howarth <paul@city-fan.org> - 5.1.2-8.alpha.cf
- Build with -O3 on ppc64 (private #1051078)

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 5.1.2-7.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr  9 2013 Paul Howarth <paul@city-fan.org> - 5.1.2-6.alpha.cf
- Fix manual page inconsistencies with help output (private #948533)
- Enable/fix the 'xzgrep -h' (private #850898)

* Thu Feb 21 2013 Paul Howarth <paul@city-fan.org> 5.1.2-5.alpha.cf
- Add support for ppc64p7 arch (Power7 optimized)

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 5.1.2-3.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> - 5.1.2-2.alpha.cf
- Update to 5.1.2alpha (see NEWS for details)

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 5.1.1-3.alpha.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Oct 17 2011 Paul Howarth <paul@city-fan.org> - 5.1.1-2.alpha.cf
- Update to 5.1.1alpha (#736318)
  - Support for multithreaded compression was added using the simplest method,
    which splits the input data into blocks and compresses them independently
    (other methods will be added in the future)
  - Added the options --single-stream and --block-size=SIZE to xz
  - xzdiff and xzgrep now support .lzo files if lzop is installed
    (the .tzo suffix is also recognized as a shorthand for .tar.lzo)
  - Support for short 8.3 filenames under DOS was added to xz; it is
    experimental and may change before it gets into a stable release

* Mon Jun 20 2011 Paul Howarth <paul@city-fan.org> - 5.0.3-2.0.cf
- Use bzipped tarball instead of gzipped one

* Mon May 23 2011 Paul Howarth <paul@city-fan.org> - 5.0.3-1.0.cf
- Update to 5.0.3
  - liblzma: a memory leak was fixed
  - liblzma: lzma_stream_buffer_encode() no longer creates an empty .xz Block
    if encoding an empty buffer; such an empty Block with LZMA2 data would
    trigger a bug in 5.0.1 and older
  - liblzma: validate function arguments better in a few functions; most
    importantly, specifying an unsupported integrity check to
    lzma_stream_buffer_encode() no longer creates a corrupt .xz file
  - liblzma: document that lzma_block_buffer_encode(), lzma_easy_buffer_encode(),
    lzma_stream_encoder(), and lzma_stream_buffer_encode() may return
    LZMA_UNSUPPORTED_CHECK
  - liblzma: the return values of the _memusage() functions are now documented
     better
  - Fix command name detection in xzgrep; xzegrep and xzfgrep now correctly use
    egrep and fgrep instead of grep
  - French translation was added

* Mon Apr  4 2011 Paul Howarth <paul@city-fan.org> - 5.0.2-1.0.cf
- Update to 5.0.2
  - LZMA2 decompressor now correctly accepts LZMA2 streams with no uncompressed
    data
  - "xz --suffix=.foo filename.foo" now refuses to compress the file due to it
    already having the suffix .foo
  - "xzgrep -l foo bar.xz" works now
  - Polish translation was added
- Nobody else likes macros for commands

* Wed Feb  9 2011 Paul Howarth <paul@city-fan.org> - 5.0.1-2.0.cf
- Remove URL tag from liblzma.pc if we have have pkgconfig ≤ 0.15
- Drop explicit dependency of devel package on pkgconfig if rpm can
  auto-detect the requirement

* Sat Jan 29 2011 Paul Howarth <paul@city-fan.org> - 5.0.1-1.0.cf
- Update to 5.0.1
  - xz --force now (de)compresses files that have setuid, setgid, or sticky bit
    set and files that have multiple hard links; the man page had it documented
    this way already but the code had a bug
  - gzip and bzip2 support in xzdiff was fixed
  - Portability fixes
  - Minor fix to Czech translation

* Mon Oct 25 2010 Paul Howarth <paul@city-fan.org> - 5.0.0-4.0.cf
- Update to the new upstream release, with liblzma.so.5
- Introduce compat-libs subpackage with liblzma.so.0 for compatibility with
  distributions using older releases

* Sun Oct 17 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.6.beta.212.gacbc
- Update to latest git snapshot

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.5.beta.20100401git
- Rebuild for i686 in RHEL-6 beta

* Thu Apr  1 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.4.beta.20100401git
- Sync with upstream (#578925)
- Add message translations, in libs package

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 4.999.9-0.3.beta.20091007git
- Move xz man pages to main package, leave lzma ones where they belong (#566484)

* Sat Dec 26 2009 Paul Howarth <paul@city-fan.org> - 4.999.9-0.2.beta.20091007git
- Import from Fedora

* Wed Oct 07 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.9-0.1.20091007.beta
- Sync with upstream again

* Fri Oct 02 2009 Jindrich Novy <jnovy@redhat.com> 4.999.9-0.1.20091002.beta
- Sync with upstream to generate the same archives on machines with different
  endianess

* Fri Aug 28 2009 Jindrich Novy <jnovy@redhat.com> 4.999.9-0.1.beta
- Update to 4.999.9beta

* Mon Aug 17 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8-0.10.beta.20090817git
- Sync with upstream because of #517806

* Tue Aug 04 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8-0.9.beta.20090804git
- Update to the latest GIT snapshot

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.999.8-0.8.beta
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 17 2009 Bill Nottingham <notting@redhat.com> - 4.999.8-0.7.beta
- Tweak summary
- Add %%check section (<tibbs@math.uh.edu>)

* Thu Jul 09 2009 Bill Nottingham <notting@redhat.com> - 4.999.8-0.6.beta
- Fix release versioning to match guidelines
- Fix up lzma-compat summary/description
- Tweak licensing

* Mon Jun 22 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.5
- Introduce lzma-compat subpackage

* Fri Jun 19 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.4
- Try to not to conflict with lzma

* Thu Jun 18 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.3
- Obsolete but don't provide lzma, they are largely incompatible
- Put beta to Release

* Wed Jun 17 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.2
- Obsolete old lzma
- Add Requires: pkgconfig

* Tue Jun 16 2009 Jindrich Novy <jnovy@redhat.com> - 4.999.8beta-0.1
- Package XZ Utils, based on LZMA Utils packaged by Per Patrice Bouchand
